# Copyright 2010 A4 Developers.  This software is licensed under the
# GNU General Public License version 3 (see the file COPYING).

"""Test suite runner for A4."""

import os
import sys
import unittest


def main():
    """Run the test suite."""
    total_tests_run = 0
    total_failures = 0
    sys.path.insert(0, 'tests')
    loader = unittest.TestLoader()

    for file_name in os.listdir('tests'):
        if not file_name.endswith('.py'):
            continue

        # Get all the test cases from the module.
        module = __import__(file_name[:-3])
        test = loader.loadTestsFromModule(module)
        result = test.run(unittest.TestResult())

        # Report the failures (if any).
        failures = result.errors + result.failures
        for parser, traceback in failures:
            print 'Failed test case:', parser.id()
            print '\n'.join('  ' + line for line in traceback.splitlines())

        total_tests_run += result.testsRun
        total_failures += len(failures)

    # Give a summary of the tests run.
    if total_failures:
        print 'Ran {0} tests ({1} failed)'.format(
            total_tests_run, total_failures)
    else:
        print 'Ran {0} tests without failures'.format(total_tests_run)


if __name__ == '__main__':
    main()
