# Copyright 2010 A4 Developers.  This software is licensed under the
# GNU General Public License version 3 (see the file COPYING).

import os
from unittest import TestCase
from testhelpers import Application, TEST_IMAGE_FILE

"""Try to open some files and see if A4 reports errors when it should."""


class TestOpeningFiles(TestCase):
    """Check that the procedure of opening a file works as expected."""

    def test_open_existent_file(self):
        """Try to open an existent file."""
        app = Application(TEST_IMAGE_FILE)
        self.assertRaises(AssertionError, app.wait_for, 'dlgError')

    def test_open_inexistent_file(self):
        """Try to open a file that doesn't exist."""
        app = Application('this-file-does-not-exist')
        # An error dialog should be shown saying that the file doesn't exist.
        dialog = app.wait_for('dlgError')
        message = dialog.gettextvalue('lblCannotopen*')
        self.assertTrue(message.endswith('No such file or directory'))
        dialog.click('btnClose')
        del dialog

    def test_open_incorrect_file(self):
        """Try to open an existent file that is not a SVG image."""
        # Open a Python script.
        app = Application(os.path.abspath(__file__))
        # An error dialog should be shown saying that the file format is
        # incorrect.
        dialog = app.wait_for('dlgError')
        message = dialog.gettextvalue('lblCannotopen*')
        self.assertTrue(message.endswith('Unknown file type'))
        dialog.click('btnClose')
        del dialog
